first_existing

Function first_existing 

pub fn first_existing(root: &str, names: &[&str]) -> Option<String>
The first of names that exists at the repo root — how these hooks decide a repo has opted into a tool.